summaryrefslogtreecommitdiff
path: root/src/camera.h
diff options
context:
space:
mode:
authordeva <deva>2005-05-03 08:31:58 +0000
committerdeva <deva>2005-05-03 08:31:58 +0000
commit16aeeeb8110893e14c2d134542981cdc0f257411 (patch)
treefbcd9ec22c27d9f82a049055ec9d37035a1e3c03 /src/camera.h
parenta8456a6a949178ff06ca66cc10c0079da9f9f067 (diff)
Removed the error object, and replaced it with a more generic info object.
Diffstat (limited to 'src/camera.h')
-rw-r--r--src/camera.h42
1 files changed, 23 insertions, 19 deletions
diff --git a/src/camera.h b/src/camera.h
index eafaf27..a75acea 100644
--- a/src/camera.h
+++ b/src/camera.h
@@ -8,32 +8,39 @@
****************************************************************************/
/*
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This file is part of MIaV.
*
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MIaV is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
*
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * MIaV is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with MIaV; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/
+
/*
* $Id$
*/
+
/*
* $Log$
+ * Revision 1.10 2005/05/03 08:31:59 deva
+ * Removed the error object, and replaced it with a more generic info object.
+ *
* Revision 1.9 2005/05/01 11:25:56 deva
* Added code to read screenshot from frame queue, decode it to rgb and put it into a qimage.
*
* Revision 1.8 2005/05/01 09:56:26 deva
* Added Id and Log tags to all files
- *
*/
+
#include <config.h>
#ifdef USE_GUI
@@ -42,7 +49,7 @@
#include <string>
using namespace std;
-#include "error.h"
+#include "info.h"
#include <stdio.h>
#include <stdlib.h>
@@ -68,7 +75,7 @@ using namespace std;
*/
class Camera {
public:
- Camera();
+ Camera(Info *ginfo);
~Camera();
void connect(const char *ip,
const int port);
@@ -82,12 +89,9 @@ public:
void unfreeze();
void snapshot(unsigned char *rgb);
- // Status methods
- Error *errorObject();
-
private:
- // Error object passed to all sub objects.
- Error *errorstatus;
+ // Info object passed to all sub objects.
+ Info *info;
bool initialized;
pthread_t playertid;